@@ -332,9 +332,14 @@ class PushTask(DockerTask):
 
         # Since docker 3.0.0, the argument of 'insecure_registry' is removed.
         # To be compatible, set 'insecure_registry=True' for old releases.
-        dc_running_ver = StrictVersion(docker.version)
-        if dc_running_ver < StrictVersion('3.0.0'):
-            kwargs['insecure_registry'] = True
+        # NOTE(frickler): The version check will fail for docker >= 6.0, but
+        # in that case we know that the workaround isn't needed.
+        try:
+            dc_running_ver = StrictVersion(docker.version)
+            if dc_running_ver < StrictVersion('3.0.0'):
+                kwargs['insecure_registry'] = True
+        except TypeError:
+            pass
 
         for response in self.dc.push(image.canonical_name, **kwargs):
             if 'stream' in response:
