@@ -166,8 +166,8 @@ class TasksTest(base.TestCase):
 
         mock_client().build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name, decode=True,
-            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
-            buildargs=None)
+            network_mode='host', nocache=False, rm=True, pull=True,
+            forcerm=True, buildargs=None)
 
         self.assertTrue(builder.success)
 
@@ -176,14 +176,14 @@ class TasksTest(base.TestCase):
     def test_build_image_with_network_mode(self, mock_client):
         self.dc = mock_client
         push_queue = mock.Mock()
-        self.conf.set_override('network_mode', 'host')
+        self.conf.set_override('network_mode', 'bridge')
 
         builder = build.BuildTask(self.conf, self.image, push_queue)
         builder.run()
 
         mock_client().build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name, decode=True,
-            network_mode='host', nocache=False, rm=True, pull=True,
+            network_mode='bridge', nocache=False, rm=True, pull=True,
             forcerm=True, buildargs=None)
 
         self.assertTrue(builder.success)
@@ -203,8 +203,8 @@ class TasksTest(base.TestCase):
 
         mock_client().build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name, decode=True,
-            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
-            buildargs=build_args)
+            network_mode='host', nocache=False, rm=True, pull=True,
+            forcerm=True, buildargs=build_args)
 
         self.assertTrue(builder.success)
 
@@ -222,8 +222,8 @@ class TasksTest(base.TestCase):
 
         mock_client().build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name, decode=True,
-            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
-            buildargs=build_args)
+            network_mode='host', nocache=False, rm=True, pull=True,
+            forcerm=True, buildargs=build_args)
 
         self.assertTrue(builder.success)
 
@@ -243,8 +243,8 @@ class TasksTest(base.TestCase):
 
         mock_client().build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name, decode=True,
-            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
-            buildargs=build_args)
+            network_mode='host', nocache=False, rm=True, pull=True,
+            forcerm=True, buildargs=build_args)
 
         self.assertTrue(builder.success)
 
@@ -529,7 +529,7 @@ class KollaWorkerTest(base.TestCase):
         """check distro_python_version for Debian"""
         self.conf.set_override('base', 'debian')
         kolla = build.KollaWorker(self.conf)
-        self.assertEqual('3.7', kolla.distro_python_version)
+        self.assertEqual('3.9', kolla.distro_python_version)
 
     def test_build_distro_python_version_rhel80(self):
         """check distro_python_version for RHEL8.0"""
@@ -648,9 +648,11 @@ class KollaWorkerTest(base.TestCase):
         kolla.images = self.images
         kolla.image_statuses_good['good'] = build.Status.BUILT
         kolla.image_statuses_bad['bad'] = build.Status.ERROR
+        kolla.image_statuses_allowed_to_fail['bad2'] = build.Status.ERROR
         kolla.image_statuses_unmatched['unmatched'] = build.Status.UNMATCHED
         results = kolla.summary()
-        self.assertEqual('error', results['failed'][0]['status'])
+        self.assertEqual('error', results['failed'][0]['status'])  # bad
+        self.assertEqual('error', results['failed'][1]['status'])  # bad2
 
     @mock.patch('shutil.copytree')
     def test_work_dir(self, copytree_mock):
@@ -664,14 +666,14 @@ class MainTest(base.TestCase):
 
     @mock.patch.object(build, 'run_build')
     def test_images_built(self, mock_run_build):
-        image_statuses = ({}, {'img': 'built'}, {}, {}, {})
+        image_statuses = ({}, {'img': 'built'}, {}, {}, {}, {})
         mock_run_build.return_value = image_statuses
         result = build_cmd.main()
         self.assertEqual(0, result)
 
     @mock.patch.object(build, 'run_build')
     def test_images_unmatched(self, mock_run_build):
-        image_statuses = ({}, {}, {'img': 'unmatched'}, {}, {})
+        image_statuses = ({}, {}, {'img': 'unmatched'}, {}, {}, {})
         mock_run_build.return_value = image_statuses
         result = build_cmd.main()
         self.assertEqual(0, result)
@@ -684,7 +686,7 @@ class MainTest(base.TestCase):
 
     @mock.patch.object(build, 'run_build')
     def test_bad_images(self, mock_run_build):
-        image_statuses = ({'img': 'error'}, {}, {}, {}, {})
+        image_statuses = ({'img': 'error'}, {}, {}, {}, {}, {})
         mock_run_build.return_value = image_statuses
         result = build_cmd.main()
         self.assertEqual(1, result)
@@ -697,14 +699,14 @@ class MainTest(base.TestCase):
 
     @mock.patch.object(build, 'run_build')
     def test_skipped_images(self, mock_run_build):
-        image_statuses = ({}, {}, {}, {'img': 'skipped'}, {})
+        image_statuses = ({}, {}, {}, {'img': 'skipped'}, {}, {})
         mock_run_build.return_value = image_statuses
         result = build_cmd.main()
         self.assertEqual(0, result)
 
     @mock.patch.object(build, 'run_build')
     def test_unbuildable_images(self, mock_run_build):
-        image_statuses = ({}, {}, {}, {}, {'img': 'unbuildable'})
+        image_statuses = ({}, {}, {}, {}, {'img': 'unbuildable'}, {})
         mock_run_build.return_value = image_statuses
         result = build_cmd.main()
         self.assertEqual(0, result)
